==> azureml_pipeline_steps-0.1.74-py3-none-any.whl: azureml/pipeline/steps/estimator_step.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""estimator_step.py."""
from azureml.pipeline.steps import PythonScriptStep
from azureml.train.estimator import MMLBaseEstimator


class EstimatorStep(PythonScriptStep):
    """Adds a step to run Estimator in a Pipeline.

    Note: The arguments to the entry script used in the Estimator object should be specified as *list* using
    'estimator_entry_script_arguments' parameter when instantiating EstimatorStep. Estimator object's parameter
    'script_params' accepts a dictionary. However 'estimator_entry_script_arguments' parameter expects arguments as
    a list.

    Estimator object initialization involves specifying a list of DataReference objects in its 'inputs' parameter.
    In Pipelines, a step can take another step's output or DataReferences as input. So when creating an EstimatorStep,
    the parameters 'inputs' and 'outputs' need to be set explicitly and that will override 'inputs' parameter
    specified in the Estimator object.

    :param name: name
    :type name: str
    :param estimator: estimator object
    :type estimator: azureml.train.estimator.Estimator
    :param inputs: inputs
    :type inputs: list[azureml.pipeline.core.builder.PipelineData, azureml.data.data_reference.DataReference]
    :param outputs: output is list of PipelineData
    :type outputs: list[azureml.pipeline.core.builder.PipelineData]
    :param allow_reuse: whether to allow reuse
    :type allow_reuse: bool
    :param version: version
    :type version: str
    """

    def __init__(self, name=None, estimator=None, estimator_entry_script_arguments=None, inputs=None, outputs=None,
                 target=None, allow_reuse=True, version=None):
        """
        Initialize EstimatorStep.

        :param name: name
        :type name: str
        :param estimator: estimator
        :type estimator: Estimator
        :param estimator_entry_script_arguments: List of command-line arguments
        :type estimator_entry_script_arguments: [str]
        :param inputs: inputs
        :type inputs: list[azureml.pipeline.core.builder.PipelineData, azureml.data.data_reference.DataReference]
        :param outputs: outputs
        :type outputs: list[azureml.pipeline.core.builder.PipelineData]
        :param target: Compute target to use
        :type target: azureml.core.compute.DsvmCompute, azureml.core.compute.BatchAiCompute,
            azureml.core.compute.RemoteTarget, azureml.core.compute_target.BatchAITarget, str
        :param allow_reuse: whether to allow reuse
        :type allow_reuse: bool
        :param version: version
        :type version: str
        """
        # the following args are required
        if None in [estimator, target]:
            raise ValueError("Estimator, target parameters are required")

        if estimator_entry_script_arguments is None:
            raise ValueError('estimator_entry_script_arguments is a required parameter. If the Estimator''s entry'
                             'script does not accept commandline arguments, set the parameter value to empty list')

        if not isinstance(estimator, MMLBaseEstimator):
            raise Exception("Estimator parameter is not of valid type")

        # resetting target, arguments and data refs as they will not be used in EstimatorStep
        estimator.run_config._target = None
        estimator.run_config.arguments = []
        estimator.run_config.data_references = []

        run_config = estimator.run_config
        source_directory = estimator.source_directory
        script_name = run_config.script

        super(EstimatorStep, self).__init__(name=name, script_name=script_name,
                                            arguments=estimator_entry_script_arguments, target=target,
                                            runconfig=run_config, inputs=inputs, outputs=outputs,
                                            source_directory=source_directory, allow_reuse=allow_reuse,
                                            version=version)

    def create_node(self, graph, default_datastore, context):
        """
        Create a node.

        :param graph: graph object
        :type graph: azureml.pipeline.core.graph.Graph
        :param default_datastore: default datastore
        :type default_datastore: azureml.core.AbstractAzureStorageDatastore, azureml.core.AzureDataLakeDatastore
        :param context: context
        :type context: _GraphContext

        :return: The created node.
        :rtype: azureml.pipeline.core.graph.Node
        """
        return super(EstimatorStep, self).create_node(graph, default_datastore, context)

==> azureml_pipeline_steps-0.1.80-py3-none-any.whl: azureml/pipeline/steps/estimator_step.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""estimator_step.py."""
from azureml.pipeline.steps import PythonScriptStep
from azureml.train.estimator import MMLBaseEstimator


class EstimatorStep(PythonScriptStep):
    """Adds a step to run Estimator in a Pipeline.

    Note: The arguments to the entry script used in the Estimator object should be specified as *list* using
    'estimator_entry_script_arguments' parameter when instantiating EstimatorStep. Estimator object's parameter
    'script_params' accepts a dictionary. However 'estimator_entry_script_arguments' parameter expects arguments as
    a list.

    Estimator object initialization involves specifying a list of DataReference objects in its 'inputs' parameter.
    In Pipelines, a step can take another step's output or DataReferences as input. So when creating an EstimatorStep,
    the parameters 'inputs' and 'outputs' need to be set explicitly and that will override 'inputs' parameter
    specified in the Estimator object.

    :param name: name
    :type name: str
    :param estimator: estimator object
    :type estimator: azureml.train.estimator.Estimator
    :param runconfig_pipeline_params: Override runconfig properties at runtime using key-value pairs each with
                                    name of the runconfig property and PipelineParameter for that property
    :type runconfig_pipeline_params: {str: PipelineParameter}
    :param inputs: inputs
    :type inputs: list[azureml.pipeline.core.builder.PipelineData, azureml.data.data_reference.DataReference]
    :param outputs: output is list of PipelineData
    :type outputs: list[azureml.pipeline.core.builder.PipelineData]
    :param allow_reuse: whether to allow reuse
    :type allow_reuse: bool
    :param version: version
    :type version: str
    """

    def __init__(self, name=None, estimator=None, estimator_entry_script_arguments=None,
                 runconfig_pipeline_params=None, inputs=None, outputs=None,
                 target=None, allow_reuse=True, version=None):
        """
        Initialize EstimatorStep.

        :param name: name
        :type name: str
        :param estimator: estimator
        :type estimator: Estimator
        :param estimator_entry_script_arguments: List of command-line arguments
        :type estimator_entry_script_arguments: [str]
        :param runconfig_pipeline_params: Override runconfig properties at runtime using key-value pairs each with
                                        name of the runconfig property and PipelineParameter for that property
        :type runconfig_pipeline_params: {str: PipelineParameter}
        :param inputs: inputs
        :type inputs: list[azureml.pipeline.core.builder.PipelineData, azureml.data.data_reference.DataReference]
        :param outputs: outputs
        :type outputs: list[azureml.pipeline.core.builder.PipelineData]
        :param target: Compute target to use
        :type target: azureml.core.compute.DsvmCompute, azureml.core.compute.BatchAiCompute,
            azureml.core.compute.RemoteTarget, azureml.core.compute_target.BatchAITarget, str
        :param allow_reuse: whether to allow reuse
        :type allow_reuse: bool
        :param version: version
        :type version: str
        """
        # the following args are required
        if None in [estimator, target]:
            raise ValueError("Estimator, target parameters are required")

        if estimator_entry_script_arguments is None:
            raise ValueError('estimator_entry_script_arguments is a required parameter. If the Estimator''s entry'
                             'script does not accept commandline arguments, set the parameter value to empty list')

        if not isinstance(estimator, MMLBaseEstimator):
            raise Exception("Estimator parameter is not of valid type")

        # resetting target, arguments and data refs as they will not be used in EstimatorStep
        estimator.run_config._target = None
        estimator.run_config.arguments = []
        estimator.run_config.data_references = []

        run_config = estimator.run_config
        source_directory = estimator.source_directory
        script_name = run_config.script

        super(EstimatorStep, self).__init__(name=name, script_name=script_name,
                                            arguments=estimator_entry_script_arguments, compute_target=target,
                                            runconfig=run_config, runconfig_pipeline_params=runconfig_pipeline_params,
                                            inputs=inputs, outputs=outputs,
                                            source_directory=source_directory, allow_reuse=allow_reuse,
                                            version=version)

    def create_node(self, graph, default_datastore, context):
        """
        Create a node.

        :param graph: graph object
        :type graph: azureml.pipeline.core.graph.Graph
        :param default_datastore: default datastore
        :type default_datastore: azureml.core.AbstractAzureStorageDatastore, azureml.core.AzureDataLakeDatastore
        :param context: context
        :type context: _GraphContext

        :return: The created node.
        :rtype: azureml.pipeline.core.graph.Node
        """
        return super(EstimatorStep, self).create_node(graph, default_datastore, context)
